pub struct Stage {
pub thread_local: bool,
pub units: Vec<SystemUnit>,
}Expand description
Discrete stage to run.
Unless a stage is marked as true in thread_local, units in this stage can be run in parallel.
Fields
thread_local: boolunits: Vec<SystemUnit>Auto Trait Implementations
impl Freeze for Stage
impl !RefUnwindSafe for Stage
impl Send for Stage
impl Sync for Stage
impl Unpin for Stage
impl !UnwindSafe for Stage